==> visualvm-1.4.1.tar.gz: visualvm-1.4.1/plugins/glassfish/src/net/java/visualvm/modules/glassfish/GlassFishOverviewPluginProvider.java <==
/*
 * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package net.java.visualvm.modules.glassfish;

import com.sun.tools.visualvm.application.Application;
import com.sun.tools.visualvm.application.type.ApplicationTypeFactory;
import com.sun.tools.visualvm.application.views.ApplicationViewsSupport;
import com.sun.tools.visualvm.core.ui.DataSourceViewPlugin;
import com.sun.tools.visualvm.core.ui.DataSourceViewPluginProvider;

/**
 * Provides a basic overview of a GlassFish application server
 * configuration and capabilities
 * @author Jaroslav Bachorik
 */
public class GlassFishOverviewPluginProvider extends DataSourceViewPluginProvider<Application> {
    private final static class InstanceProvider {
        public static final GlassFishOverviewPluginProvider INSTANCE = new GlassFishOverviewPluginProvider();
    }
    
    @Override
    protected DataSourceViewPlugin createPlugin(Application app) {
        return new GlassFishOverviewPlugin(app);
    }

    @Override
    protected boolean supportsPluginFor(Application app) {
        return (ApplicationTypeFactory.getApplicationTypeFor(app) instanceof GlassFishApplicationType);
    }

    public static void initialize() {
        ApplicationViewsSupport.sharedInstance().getOverviewView().
                registerPluginProvider(InstanceProvider.INSTANCE);
    }
    
    public static void shutdown() {
        ApplicationViewsSupport.sharedInstance().getOverviewView().
                unregisterPluginProvider(InstanceProvider.INSTANCE);
    }
}

==> visualvm-2.1.8.tar.gz: visualvm-2.1.8/plugins/glassfish/src/net/java/visualvm/modules/glassfish/GlassFishOverviewPluginProvider.java <==
/*
 * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package net.java.visualvm.modules.glassfish;

import org.graalvm.visualvm.application.Application;
import org.graalvm.visualvm.application.type.ApplicationTypeFactory;
import org.graalvm.visualvm.application.views.ApplicationViewsSupport;
import org.graalvm.visualvm.core.ui.DataSourceViewPlugin;
import org.graalvm.visualvm.core.ui.DataSourceViewPluginProvider;

/**
 * Provides a basic overview of a GlassFish application server
 * configuration and capabilities
 * @author Jaroslav Bachorik
 */
public class GlassFishOverviewPluginProvider extends DataSourceViewPluginProvider<Application> {
    private final static class InstanceProvider {
        public static final GlassFishOverviewPluginProvider INSTANCE = new GlassFishOverviewPluginProvider();
    }
    
    @Override
    protected DataSourceViewPlugin createPlugin(Application app) {
        return new GlassFishOverviewPlugin(app);
    }

    @Override
    protected boolean supportsPluginFor(Application app) {
        return (ApplicationTypeFactory.getApplicationTypeFor(app) instanceof GlassFishApplicationType);
    }

    public static void initialize() {
        ApplicationViewsSupport.sharedInstance().getOverviewView().
                registerPluginProvider(InstanceProvider.INSTANCE);
    }
    
    public static void shutdown() {
        ApplicationViewsSupport.sharedInstance().getOverviewView().
                unregisterPluginProvider(InstanceProvider.INSTANCE);
    }
}
